import React, { useState, useEffect } from 'react';
import { getHealth, getAvailability, setAvailability } from './api';

const NameForm = ({ onNameSet }) => {
  const [name, setName] = useState("");

  return (
    <div>
      <input type="text" onChange={({ target }) => setName(target.value)}></input>
      <button disabled={name === ""} onClick={onNameSet}>Set Name</button>
    </div>
  )
}

const colors = {
  yes: "#0f0",
  no: "#f00",
  maybe: "#ff0",
}

const pad = num => {
  let snum = "" + num
  if (snum.length === 1) snum = "0" + snum
  return snum
}

const Tile = ({ month, day, availability, onClick }) => (
  <div onClick={onClick}>
    <span>{pad(month)}/{pad(day)}</span>
    {
      availability
        .filter(({ status }) => status && status !== "unknown")
        .map(({ name, status }) => (
          <span 
            key={name} 
            style={{ color: colors[status] }}
          >
            {name}
          </span>
        ))
      }
  </div>
);



function App() {
  const [name, setName] = useState(null);
  const [avail, setAvail] = useState(null);
  useEffect(() => { getAvailability().then(setAvail) }, []);


  if (name === null) {
    return <NameForm onNameSet={setName} />
  }

  if (avail === null) {
    return <span>Loading...</span>
  }

  return (
    <div>
      <Tile month={6} day={1} availability={[
        { name: "Foo", status: "unknown" },
        { name: "Bar", status: "yes" },
        { name: "Baz", status: "no" },
        { name: "Bix", status: "maybe" },
      ]}/>
      {JSON.stringify(avail)}
      <button onClick={() => getHealth().then(console.log)}>Get Status</button>
      <button onClick={() => getAvailability().then(setAvail)}>Get Avail</button>
      <button onClick={() => setAvailability({})}>Set Avail</button>
    </div>
  );
}

export default App;
